| BRANCH  | STATUS                                                                                                                                                                                                                                          |
|---------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| main    | [![Unit-Testing, Coverage, Linting](https://github.com/btr1975/zapish-logger/actions/workflows/test-coverage-lint.yml/badge.svg?branch=main)](https://github.com/btr1975/zapish-logger/actions/workflows/test-coverage-lint.yml)    |
| develop | [![Unit-Testing, Coverage, Linting](https://github.com/btr1975/zapish-logger/actions/workflows/test-coverage-lint.yml/badge.svg?branch=develop)](https://github.com/btr1975/zapish-logger/actions/workflows/test-coverage-lint.yml) |

[![Downloads](https://pepy.tech/badge/zapish-logger)](https://pepy.tech/project/zapish-logger)
[![Supported Versions](https://img.shields.io/pypi/pyversions/zapish-logger.svg)](https://pypi.org/project/zapish-logger)
[![Documentation Status](https://readthedocs.org/projects/zapish-logger/badge/?version=latest)](https://zapish-logger.readthedocs.io/en/latest/?badge=latest)


# zapish-logger

## Description
* A simple logger that logs in a JSON format inspired by go zap

#### Generated by CookieCutter
* Repository: [GitHub](https://github.com/btr1975/cookiecutter-python-library)
* Version: 1.0.3
